from .. import __package__ as base_package
import os
import bpy
import json
from bpy.types import Menu
from .funcs import pref, name_from_path

class CT_MT_templates_menu(Menu):
    bl_label = "Manage your custom templates"
    bl_description = "Import, export, add from folder (with controllable recursion depth), clear current templates"

    def draw(self, context):
        layout = self.layout
        layout.operator("ct.add_templates_from_folder",
                        text="Add from folder", icon="ADD")
        layout.operator(
            "ct.clear", text="Clear current templates", icon="TRASH")
        layout.separator()
        layout.operator("ct.import_templates",
                        text="Import templates", icon="IMPORT")
        layout.operator("ct.export_templates",
                        text="Export templates", icon="EXPORT")

class CT_MT_splash_mode(Menu):
    bl_idname = "CT_MT_splash_mode"
    bl_label = "Custom Templates Switch"
    bl_description = "Swtich between Blender's default and your Custom Templates"

    def draw(self, context):
        layout = self.layout
        prefs = pref()
            
        layout.operator("ct.open_preferences", text="Manage templates")
        layout.separator()
        layout.prop(prefs, "override_splash")

class CT_MT_more_templates(Menu):
    bl_idname = "CT_MT_more_templates"
    bl_label = "Other Custom Templates"
    bl_description = "Show the other templates in the splash screen"

    def draw(self, context):
        layout = self.layout
        prefs = pref()
        
        for t in prefs.projects[4:]:
            layout.operator(
                "wm.read_homefile", text=(t.name if t.name else name_from_path(t.path)), icon="FILE_NEW").filepath = t.path

class CT_MT_workspace_add(Menu):
    bl_label = "Add workspace from Custom Templates"

    def draw(self, context):
        layout = self.layout
        templates = pref().projects
        layout.label(text="Add workspace from Custom Templates", icon="ADD")
        layout.separator()
        for i in range(len(templates)):
            t = templates[i]
            layout.operator("CT_OT_template_workspaces", text=t.name).index = i
